
# SASAIR (SAS Atmosphere Interface & Retrieval)

## Description

SASAIR is a Python package with Python client implementations for some common Air pollution and atmosphere related public API's.


## Installation with pip

To install the package, you can use the following command:

```bash
pip config set global.extra-index-url https://repo.vito.be/artifactory/api/pypi/marvin-projects-pypi-local/simple
pip install sasair 
```


## Building from Source

TODO


## Configuration

TODO


## Usage

Here are some example usages of the package:
TODO


## Contributing

If you want to contribute to spio, please follow the standard contributing guidelines and push your changes to a new branch in
https://git.vito.be/projects/MARVIN/repos/sasair


## Testing

TODO

## CI/CD

TODO


### Updating the Package Version

To update the package version:

1. Tag the code with the new version number in the format `major.minor.fix`.
2. Push the tagged code to the appropriate branch.

### Pipeline Automation

The CI/CD pipeline is fully automated using Jenkins. Pipeline details are defined in the `Jenkinsfile` located in the repository root.

## Contact

For questions or issues, please reach out to the project maintainers:

- **Roeland Maes**: [roeland.maes@vito.be](mailto:roeland.maes@vito.be)


## License

This project is licensed under the MIT License. See the `LICENSE.md` file for details.
